pattern

Macro pattern 

pattern!() { /* proc-macro */ }
Parse a binary pattern and generate an instance of GenericBinaryPattern at compile time.
An exhausive overview of the pattern syntax and operads can be found here: bmatcher.

Example

static MY_PATTERN: &dyn BinaryPattern = &pattern!("01 02 ? 03 [4]");