Parse a binary pattern and generate an instance of [bmatcher::BorrowedBinaryPattern] at compile time.
An exhausive overview of the pattern syntax and operads can be found here: [bpattern::doc_pattern_syntax].
Example
ⓘstatic MY_PATTERN: &dyn BinaryPattern = &pattern!("01 02 ? 03 [4]");